from pi_pico_co2_grove import *
from machine import Pin, UART
from time import sleep_ms


# Initialisation liaison série
uart0 = UART(0, baudrate=9600)                                        # Création d'un objet uart0
uart0.init(9600, bits=8, parity=None, stop=1, tx=Pin(0), rx=Pin(1) )  # paramètres de la liaison série

# Correction décalage du thermomètre (dépend du module/capteur)
TEMP_OFFSET = const(5)

# Instance du capteur
sensor = MHZ16(uart0, temp_offset = TEMP_OFFSET)

# Doit-on recalibrer le capteur ?
calibrate = False

# Doit-on préchauffer le capteur ?
preheat = False

# Démarrage de la calibration (dans une pièce aérée ou à l'extérieur)

if preheat:
	print("Préchauffe (5 minutes)")
	sensor.preheat()

if calibrate:
	print("Calibration\n")
	sensor.calibrate()

# Précision du capteur (ppm)
#ACCURACY = const(200)

# Seuil de détection haut du capteur (ppm)
THRESHOLD = const(2000)

while True:
	# Lance une mesure
	(temp_celsius, co2_ppm) = sensor.measure()
	
	# Si les valeurs remontées sont positives
	if temp_celsius != -1 and co2_ppm != -1:
	
		# Affiche  la température et la concentration de CO2
		print("Temperature : %d °C" %temp_celsius)

		if co2_ppm < THRESHOLD:
			print("Concentration en CO2 : %d ppm\n" %co2_ppm)
		else:
			print("Concentration en CO2 > %d ppm\n" %THRESHOLD)

	else:
		print("Problème de mesure")

	# Temporisation de cinq secondes
	sleep_ms(5000)
